:mod:`ordec.lib.generic_mos` --- Generic MOS library
====================================================

.. automodule:: ordec.lib.generic_mos
  :members:
  :undoc-members:
  :exclude-members: instances, netlist_ngspice, discoverable_instances
